@@ -73,10 +73,6 @@ sub setup {
 	# Values for upload script
 	$config->define('upload_actions', 'An array of commands to run on each file to be uploaded. Each component is passed through Mojo::Template before processing. To avoid quoting issues, it is a two-dimensional array, so that no shell will be called to run this.', [['echo', '<%== $file %>', 'ready for upload']]);
 
-	# Values for schedule parser
-	$config->define("schedule_flavour", "The SReview::Schedule::Parser package that can parse the conference's schedule", 'none');
-	$config->define("schedule_url", "The URL for the parseable conference schedule", undef);
-
 	return $config;
 }
 
